==> nedi-1.0.7p0.tgz: nedi/html/languages/english/gui.php <==
<?PHP
// English language file, Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually precede nouns
$verb1		= 1;

//Labels
$acklbl		= "Acknowledge";
$acslbl		= "Access";
$addlbl		= "Add";
$adrlbl		= "Address";
$alllbl		= "All";
$alrlbl		= "Already";
$agelbl		= "Age";
$altlbl		= "Alternative";
$arclbl		= "Arc";
$avalbl		= "Availability";
$avglbl		= "Average";
$buplbl		= "Backup";
$bwdlbl		= "Bandwidth";
$cfglbl		= "Configuration";
$chglbl		= "Change";
$clalbl		= "Class";
$cmblbl		= "Combination";
$cmdlbl		= "Execute";
$cmplbl		= "Comparison";
$cmtlbl		= "Comment";
$cnclbl		= "Connection";
$cndlbl		= "Condition";
$conlbl		= "Contact";
$coplbl		= "Copy";
$cuslbl		= "Custom";
$dellbl		= "Delete";
$deplbl		= "Dependencies";
$deslbl		= "Description";
$dislbl		= "Distribution";
$dsclbl		= "Discover";
$duplbl		= "Duplicate";
$durlbl		= "Duration";
$collbl		= "Columns";
$dstlbl		= "Destination";
$edilbl		= "Edit";
$emplbl		= "Empty";
$endlbl		= "End";
$errlbl		= "Errors";
$explbl		= "Export";
$faslbl		= "Fast";
$fltlbl		= "Filter";
$fillbl		= "Files";
$fislbl		= "First";
$frelbl		= "Free";
$frmlbl		= "Format";
$fullbl		= "Full";
$fwdlbl		= "Forward";
$gralbl		= "Graphs";
$grdlbl		= "Degrees";
$grplbl		= "Groups";
$hislbl		= "History";
$imglbl		= "Images";
$implbl		= "Import";
$inblbl		= "Inbound";
$invlbl		= "Inventory";
$isolbl		= "Isolated";
$laslbl		= "Last";
$latlbl		= "Latency";
$lenlbl		= "Length";
$levlbl		= "Level";
$limlbl		= "Limit";
$loclbl		= "Location";
$lodlbl		= "Load";
$loslbl		= "Lost";
$lstlbl		= "List";
$manlbl		= "Main";
$maxlbl		= "Maximum";
$mdllbl		= "Model";
$memlbl		= "Memory";
$metlbl		= "Metric";
$mgtlbl		= "Management";
$msglbl		= "Events";
$msklbl		= "Mask";
$mullbl		= "Multiple";
$namlbl		= "Name";
$netlbl		= "Network";
$neblbl		= "Neighbor";
$newlbl		= "New";
$nomlbl		= "Nomads";
$nonlbl		= "None";
$nodlbl		= "Node";
$numlbl		= "Number";
$optlbl		= "Optimize";
$orilbl		= "Original";
$oublbl		= "Outbound";
$poplbl		= "Population";
$prilbl		= "Priority";
$qutlbl		= "Quiet";
$rnglbl		= "Range";
$realbl		= "Read";
$replbl		= "Repair";
$reslbl		= "Reset";
$rotlbl		= "Rotate";
$rltlbl		= "Realtime";
$seclbl		= "Security";
$sellbl		= "Select";
$serlbl		= "Serial#";
$sholbl		= "Show";
$shplbl		= "Shape";
$sizlbl		= "Size";
$slolbl		= "Slow";
$sndlbl		= "Send";
$spdlbl		= "Speed";
$srclbl		= "Source";
$srtlbl		= "Sort";
$srvlbl		= "Services";
$stalbl		= "Status";
$strlbl		= "Straight";
$stslbl		= "Statistics";
$sttlbl		= "Start";
$sumlbl		= "Summary";
$tgtlbl		= "Targets";
$timlbl		= "Time";
$tmplbl		= "Temperature";
$totlbl		= "Total";
$trflbl		= "Traffic";
$typlbl		= "Type";
$undlbl		= "Undiscovered";
$updlbl		= "Update";
$upllbl		= "Upload";
$usrlbl		= "User";
$vallbl		= "Values";
$venlbl		= "Vendor";
$verlbl		= "Version";
$woulbl		= "Without";
$wrtlbl		= "Write";
$wtylbl		= "Warranty";

// Statements
$nokmsg		= "<h4>You're not authorized for this!</h4>\n";
$toumsg		= "<h4>Timeout exceeded or no result!</h4>\n";
$lopmsg		= "already exists in path (Could be a routing loop)!\n";
$cfmmsg         = "Are you sure?";

// Time
$tim['n']	= "Now";
$tim['t']	= "Today";
$tim['s']	= "Seconds";
$tim['i']	= "Minutes";
$tim['h']	= "Hours";
$tim['d']	= "Days";
$tim['w']	= "Weeks";
$tim['m']	= "Months";
$tim['y']	= "Years";

// Sizes
$siz['t']	= "Tiny";
$siz['s']	= "Small";
$siz['m']	= "Medium";
$siz['l']	= "Large";
$siz['x']	= "X-large";

// Places
$place['r']	= "Region";
$place['c']	= "City";
$place['b']	= "Building";
$place['f']	= "Floor";
$place['o']	= "Room";
$place['a']	= "Rack";

// Message Levels
$mlvl['10']	= "Other";
$mlvl['50']	= "Info";
$mlvl['100']	= "Notice";
$mlvl['150']	= "Warning";
$mlvl['200']	= "Alert";
$mlvl['250']	= "Emergency";

// Stock Condition Levels
$stco['10']  	= "New";
$stco['100'] 	= "Active";
$stco['150'] 	= "Used";
$stco['200'] 	= "Broken";

// Incident Groups
$igrp['1']	= "New";
$igrp['10']	= "Facility";
$igrp['11']	= "Power Outtage";
$igrp['12']	= "Construction Work";
$igrp['13']	= "Forces of Nature";
$igrp['14']	= "Serviceprovider";
$igrp['20']	= "Equipment";
$igrp['21']	= "Power Supply";
$igrp['22']	= "Chassis";
$igrp['23']	= "Module";
$igrp['24']	= "Software";
$igrp['25']	= "Traffic";
$igrp['30']	= "People";
$igrp['31']	= "Maintenance";
$igrp['32']	= "Config Fault";
$igrp['33']	= "Customer";
$igrp['34']	= "Hacker Attack";

?>

==> nedi-1.0.8p11.tgz: nedi/html/languages/english/gui.php <==
<?PHP
// English language file, Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually precede nouns
$verb1		= 1;

//Labels
$acklbl		= "Acknowledge";
$acslbl		= "Access";
$actlbl		= "Action";
$addlbl		= "Add";
$adrlbl		= "Address";
$alllbl		= "All";
$alrlbl		= "Already";
$agelbl		= "Age";
$altlbl		= "Alternative";
$arclbl		= "Arc";
$avalbl		= "Availability";
$avglbl		= "Average";
$buplbl		= "Backup";
$bwdlbl		= "Bandwidth";
$cfglbl		= "Configuration";
$chglbl		= "Change";
$clalbl		= "Class";
$cmblbl		= "Combination";
$cmdlbl		= "Execute";
$cmplbl		= "Comparison";
$cmtlbl		= "Comment";
$cnclbl		= "Connection";
$cndlbl		= "Condition";
$collbl		= "Columns";
$conlbl		= "Contact";
$coplbl		= "Copy";
$cuslbl		= "Custom";
$dcalbl		= "Discard";
$dellbl		= "Delete";
$deplbl		= "Dependencies";
$deslbl		= "Description";
$dislbl		= "Distribution";
$dsalbl		= "Disabled";
$dsclbl		= "Discover";
$duplbl		= "Duplicate";
$durlbl		= "Duration";
$drplbl		= "Drop";
$dstlbl		= "Destination";
$edilbl		= "Edit";
$emplbl		= "Empty";
$endlbl		= "End";
$errlbl		= "Errors";
$explbl		= "Export";
$faslbl		= "Fast";
$fltlbl		= "Filter";
$fillbl		= "File";
$fislbl		= "First";
$frelbl		= "Free";
$frmlbl		= "Format";
$fullbl		= "Full";
$fwdlbl		= "Forward";
$gralbl		= "Graphs";
$grdlbl		= "Degrees";
$grplbl		= "Group";
$hislbl		= "History";
$icelbl		= "Invoice";
$imglbl		= "Images";
$implbl		= "Import";
$inblbl		= "Inbound";
$inclbl		= "Incident";
$invlbl		= "Inventory";
$idxlbl		= "Index";
$inflbl		= "Information";
$icelbl		= "Invoice";
$isolbl		= "Isolated";
$laslbl		= "Last";
$latlbl		= "Latency";
$lenlbl		= "Length";
$levlbl		= "Level";
$limlbl		= "Limit";
$loclbl		= "Location";
$lodlbl		= "Load";
$loglbl		= "Log";
$loslbl		= "Lost";
$lstlbl		= "List";
$manlbl		= "Main";
$maxlbl		= "Maximum";
$memlbl		= "Memory";
$metlbl		= "Metric";
$mdllbl		= "Model";
$mgtlbl		= "Management";
$modlbl		= "Mode";
$monlbl		= "Monitor";
$msglbl		= "Events";
$msklbl		= "Mask";
$mullbl		= "Multiple";
$namlbl		= "Name";
$netlbl		= "Network";
$neblbl		= "Neighbor";
$newlbl		= "New";
$nodlbl		= "Node";
$notlbl		= "Not";
$nomlbl		= "Nomads";
$nonlbl		= "None";
$numlbl		= "Number";
$opolbl		= "Options";
$optlbl		= "Optimize";
$orilbl		= "Original";
$oublbl		= "Outbound";
$paslbl		= "Password";
$poplbl		= "Population";
$porlbl		= "Port";
$prolbl		= "Protocol";
$prilbl		= "Priority";
$qutlbl		= "Quiet";
$rcvlbl		= "Read";
$realbl		= "Read";
$replbl		= "Repair";
$reslbl		= "Reset";
$rnglbl		= "Range";
$rotlbl		= "Rotate";
$rltlbl		= "Realtime";
$rpllbl		= "Replace";
$rptlbl		= "Repeat";
$seclbl		= "Security";
$sellbl		= "Select";
$serlbl		= "Serial#";
$sholbl		= "Show";
$shplbl		= "Shape";
$sizlbl		= "Size";
$slolbl		= "Slow";
$sndlbl		= "Send";
$spdlbl		= "Speed";
$srclbl		= "Source";
$srtlbl		= "Sort";
$srvlbl		= "Services";
$stalbl		= "Status";
$strlbl		= "Straight";
$stslbl		= "Statistics";
$sttlbl		= "Start";
$sumlbl		= "Summary";
$tgtlbl		= "Target";
$timlbl		= "Time";
$titlbl		= "Title";
$tmplbl		= "Temperature";
$toplbl		= "Top";
$totlbl		= "Total";
$trflbl		= "Traffic";
$tstlbl		= "Test";
$typlbl		= "Type";
$undlbl		= "Undiscovered";
$updlbl		= "Update";
$upllbl		= "Upload";
$uptlbl		= "Uptime";
$usrlbl		= "User";
$vallbl		= "Values";
$venlbl		= "Vendor";
$verlbl		= "Version";
$woulbl		= "Without";
$wrtlbl		= "Write";
$wtylbl		= "Warranty";

// Statements
$cfmmsg         = "are you sure?";
$delmsg		= "will be deleted";
$lopmsg		= "already exists in path (Could be a routing loop)!\n";
$nokmsg		= "<h4>You're not authorized for this!</h4>\n";
$toumsg		= "<h4>Timeout exceeded or no result!</h4>\n";

// Time
$tim['n']	= "Now";
$tim['t']	= "Today";
$tim['s']	= "Seconds";
$tim['i']	= "Minutes";
$tim['h']	= "Hours";
$tim['d']	= "Days";
$tim['w']	= "Weeks";
$tim['m']	= "Months";
$tim['y']	= "Years";

// Sizes
$siz['t']	= "Tiny";
$siz['s']	= "Small";
$siz['m']	= "Medium";
$siz['l']	= "Large";
$siz['x']	= "X-large";

// Places
$place['r']	= "Region";
$place['c']	= "City";
$place['b']	= "Building";
$place['f']	= "Floor";
$place['o']	= "Room";
$place['a']	= "Rack";

// Message Levels
$mlvl['10']	= "Other";
$mlvl['50']	= "Info";
$mlvl['100']	= "Notice";
$mlvl['150']	= "Warning";
$mlvl['200']	= "Alert";
$mlvl['250']	= "Emergency";

// Stock Condition Levels
$stco['10']  	= "New";
$stco['100'] 	= "Active";
$stco['150'] 	= "Used";
$stco['200'] 	= "Broken";
$stco['250'] 	= "Unknown";

// Incident Groups
$igrp['1']	= "New";
$igrp['10']	= "Facility";
$igrp['11']	= "Power Outtage";
$igrp['12']	= "Construction Work";
$igrp['13']	= "Forces of Nature";
$igrp['14']	= "Serviceprovider";
$igrp['15']	= "Wildlife";
$igrp['20']	= "Equipment";
$igrp['21']	= "Power Supply";
$igrp['22']	= "Chassis";
$igrp['23']	= "Module";
$igrp['24']	= "Software";
$igrp['25']	= "Traffic";
$igrp['30']	= "People";
$igrp['31']	= "Maintenance";
$igrp['32']	= "Config Fault";
$igrp['33']	= "Customer";
$igrp['34']	= "Hacker Attack";

?>
